@@ -25,10 +25,13 @@ class SMSReceivedResult(object):
 
             response = Functions.__parsejson__(self,r.text)
 
-            if response["Result"]:
+            if "Result" in response:
                 self.Result = response["Result"]
 
-            if self.Result == "Success":
+            if "Status" in response:
+                self.Result = response["Status"]
+
+            if self.Result == "Success" and "Data" in response:
                 if response["Data"]["SMSReceived"]:
                     for key in response["Data"]["SMSReceived"]:
                         self.SMSReceived.append(key)
