@@ -23,13 +23,13 @@ class StatusRequestResult(object):
 
             response = Functions.__parsejson__(self,r.text)
 
-            if response["Result"]:
+            if "Result" in response:
                 self.Result = response["Result"]
 
-            if response["MessageID"]:
+            if "MessageID" in response:
                 self.MessageID = response["MessageID"]
 
-            if response["Data"]:
+            if "Data" in response:
                 for key in response["Data"]:
                     if key == "Status":
                         self.Status = response["Data"][key]
