@@ -13,8 +13,16 @@ class Common:
 
     """ Constructor """
     def __init__(self,kwargs):
+
+        self.Sender          = _config.__Sender__
+        self.APIKey          = _config.__APIKey__
+        self.APIVersion      = _config.__APIVersion__
+        self.APIURL          = _config.__APIURL__
+        self.APIHeaders      = _config.__APIHeaders__
+
+        self.MessageID      = ""
         
-        self.SetArgs(kwargs)
+        self.SetArgsCommon(kwargs)
 
     """ Destructor """
     def __del__(self):
@@ -27,7 +35,7 @@ class Common:
         self.MessageID       = ""
 
     """ Set Args """
-    def SetArgs(self, kwargs):
+    def SetArgsCommon(self, kwargs):
 
         if "Sender" in kwargs:
             self.Sender = _config.__Sender__ = kwargs.pop("Sender")
