@@ -31,9 +31,36 @@ class Common:
     SendMode        = ""
 
     """ Constructor """
-    def __init__(self,kwargs):
+    def __init__(self, kwargs):
 
-        self.SetArgs(kwargs)
+        #print("super().__init__()")
+
+        self.Sender          = _config.__Sender__
+        self.APIKey          = _config.__APIKey__
+        self.APIVersion      = _config.__APIVersion__
+        self.APIURL          = _config.__APIURL__
+        self.APIHeaders      = _config.__APIHeaders__
+
+        self.ErrorEmailNotify    = ""
+
+        self.WebhookCallbackURL      = ""
+        self.WebhookCallbackFormat   = ""
+
+        self.MessageID       = ""
+        
+        self.Reference       = ""
+        self.SendTime        = ""
+        self.Timezone        = "New Zealand"
+        self.SubAccount      = ""
+        self.Department      = ""
+        self.ChargeCode      = ""
+
+        self.Attachments     = []
+        self.Recipients      = []
+
+        self.SendMode        = ""
+
+        self.SetArgsCommon(kwargs)
 
     def __del__(self):
         self.Sender          = ""
@@ -62,10 +89,11 @@ class Common:
         self.SendMode        = ""
     
 
-    """ Set Args """
-    def SetArgs(self, kwargs):
+    """ Set Common Args """
+    def SetArgsCommon(self, kwargs):
 
-        #print("SetArgs()")
+        #print("super().SetArgs()")
+        #print(kwargs)
 
         if "Sender" in kwargs:
             self.Sender = _config.__Sender__ = kwargs.pop("Sender")
