@@ -19,9 +19,9 @@ class Email(Common):
     """ Constructor """
     def __init__(self, kwargs):
 
-        #super().__init__(kwargs)
+        super().__init__(kwargs)
 
-        self.SetArgs(kwargs)
+        self.SetArgsChild(kwargs)
     
     """ Destructor """
     def __del__(self):
@@ -35,9 +35,9 @@ class Email(Common):
         self.ReplyTo         = ""
     
     """ Set Args """
-    def SetArgs(self, kwargs):
+    def SetArgsChild(self, kwargs):
 
-        super().SetArgs(kwargs)
+        #super().SetArgs(kwargs)
 
         for key, value in kwargs.items():
 
@@ -70,10 +70,10 @@ class Email(Common):
             "APIKey": self.APIKey,
             "MessageType": "Email",
             "APIVersion": self.APIVersion,
-            "MessageID" : self.MessageID,
             "MessageData" :
             {
                 "Mode": self.SendMode,
+                "MessageID" : self.MessageID,
                 "ErrorEmailNotify": self.ErrorEmailNotify,
                 "WebhookCallbackURL": self.WebhookCallbackURL,
                 "WebhookCallbackFormat": self.WebhookCallbackFormat,
@@ -117,7 +117,9 @@ class Email(Common):
     """ Function to send message """
     def SendMessage(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
+
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
@@ -142,7 +144,8 @@ class Email(Common):
     """ Async Function to send message """
     async def SendMessageAsync(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
