@@ -19,9 +19,9 @@ class Fax(Common):
     """ Constructor """
     def __init__(self, kwargs):
 
-        #super().__init__(kwargs)
+        super().__init__(kwargs)
 
-        self.SetArgs(kwargs)
+        self.SetArgsChild(kwargs)
 
     """ Destructor """
     def __del__(self):
@@ -35,9 +35,9 @@ class Fax(Common):
         self.RetryPeriod		= 0
 
     """ Update Data """
-    def SetArgs(self, kwargs):
+    def SetArgsChild(self, kwargs):
 
-        super().SetArgs(kwargs)
+        #super().SetArgs(kwargs)
 
         for key, value in kwargs.items():
 
@@ -73,10 +73,10 @@ class Fax(Common):
             "APIKey": self.APIKey,
             "MessageType": "Fax",
             "APIVersion": self.APIVersion,
-            "MessageID" : self.MessageID,
             "MessageData" :
             {
                 "Mode": self.SendMode,
+                "MessageID" : self.MessageID,
                 
                 "ErrorEmailNotify": self.ErrorEmailNotify,
                 "WebhookCallbackURL": self.WebhookCallbackURL,
@@ -120,7 +120,8 @@ class Fax(Common):
     """ Function to send message """
     def SendMessage(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
@@ -142,7 +143,8 @@ class Fax(Common):
     """ Async Function to send message """
     async def SendMessageAsync(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
