@@ -15,9 +15,9 @@ class SMS(Common):
     """ Constructor """
     def __init__(self, kwargs):
         
-        #super().__init__(kwargs)
+        super().__init__(kwargs)
 
-        self.SetArgs(kwargs)
+        self.SetArgsChild(kwargs)
 
     """ Destructor """
     def __del__(self):
@@ -27,9 +27,9 @@ class SMS(Common):
         self.MessageText    = ""
 
     """ Update Data """
-    def SetArgs(self, kwargs):
+    def SetArgsChild(self, kwargs):
 
-        super().SetArgs(kwargs)
+        #print("sms().SetArgs()")
 
         for key, value in kwargs.items():
 
@@ -53,10 +53,11 @@ class SMS(Common):
             "APIKey": self.APIKey,
             "MessageType": "SMS",
             "APIVersion": self.APIVersion,
-            "MessageID" : self.MessageID,
+
             "MessageData" :
             {
                 "Mode": self.SendMode,
+                "MessageID" : self.MessageID,
 
                 "ErrorEmailNotify": self.ErrorEmailNotify,
                 "WebhookCallbackURL": self.WebhookCallbackURL,
@@ -98,7 +99,8 @@ class SMS(Common):
     """ Function to send message """
     def SendMessage(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
@@ -106,8 +108,13 @@ class SMS(Common):
         if not self.APIKey :
             return MessageResult(error="Empty API Key")
 
-        if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
-            return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
+        if self.WebhookCallbackURL :
+
+            if not self.WebhookCallbackFormat :
+                return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
+
+            if self.WebhookCallbackFormat.upper() != "JSON" and self.WebhookCallbackFormat.upper() != "XML" :
+                return MessageResult(error="Invalid WebhookCallbackFormat - JSON or XML")
         
         if not self.MessageText:
             return MessageResult(error="Emtpy Message Text")
@@ -120,7 +127,8 @@ class SMS(Common):
     """ Async Function to send message """
     async def SendMessageAsync(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
@@ -128,8 +136,13 @@ class SMS(Common):
         if not self.APIKey :
             return MessageResult(error="Empty API Key")
 
-        if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
-            return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
+        if self.WebhookCallbackURL :
+
+            if not self.WebhookCallbackFormat :
+                return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
+
+            if self.WebhookCallbackFormat.upper() != "JSON" and self.WebhookCallbackFormat.upper() != "XML" :
+                return MessageResult(error="Invalid WebhookCallbackFormat - JSON or XML")
         
         if not self.MessageText:
             return MessageResult(error="Emtpy Message Text")
