@@ -31,9 +31,9 @@ class TTS(Common):
     """ Constructor """
     def __init__(self, kwargs):
 
-        #super().__init__(kwargs)
+        super().__init__(kwargs)
 
-        self.SetArgs(kwargs)
+        self.SetArgsChild(kwargs)
 
     """ Destructor """
     def __del__(self):
@@ -55,9 +55,9 @@ class TTS(Common):
         self.CallRouteMessageOnWrongKey  = ""
 
     """ Set Args """
-    def SetArgs(self, kwargs):
+    def SetArgsChild(self, kwargs):
 
-        super().SetArgs(kwargs)
+        #super().SetArgs(kwargs)
 
         for key, value in kwargs.items():
 
@@ -108,10 +108,10 @@ class TTS(Common):
             "APIKey": self.APIKey,
             "MessageType": "TextToSpeech",
             "APIVersion": self.APIVersion,
-            "MessageID" : self.MessageID,
             "MessageData" :
             {
                 "Mode": self.SendMode,
+                "MessageID" : self.MessageID,
 
                 "ErrorEmailNotify": self.ErrorEmailNotify,
                 "WebhookCallbackURL": self.WebhookCallbackURL,
@@ -178,7 +178,8 @@ class TTS(Common):
     """ Function to send message """
     def SendMessage(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
@@ -200,7 +201,8 @@ class TTS(Common):
     """ Async Function to send message """
     async def SendMessageAsync(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
@@ -223,4 +225,4 @@ class TTS(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
-        return 'SMS(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
+        return 'TTS(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
