@@ -31,9 +31,9 @@ class Voice(Common):
     """ Constructor """
     def __init__(self, kwargs):
 
-        #super().__init__(kwargs)
+        super().__init__(kwargs)
 
-        self.SetArgs(kwargs)
+        self.SetArgsChild(kwargs)
 
     """ Destructor """
     def __del__(self):
@@ -56,9 +56,9 @@ class Voice(Common):
         self.Keypads     =[]
 
     """ Set Args """
-    def SetArgs(self, kwargs):
+    def SetArgsChild(self, kwargs):
 
-        super().SetArgs(kwargs)
+        #super().SetArgs(kwargs)
 
         for key, value in kwargs.items():
 
@@ -109,10 +109,10 @@ class Voice(Common):
             "APIKey": self.APIKey,
             "MessageType": "Voice",
             "APIVersion": self.APIVersion,
-            "MessageID" : self.MessageID,
             "MessageData" :
             {
                 "Mode": self.SendMode,
+                "MessageID" : self.MessageID,
 
                 "ErrorEmailNotify": self.ErrorEmailNotify,
                 "WebhookCallbackURL": self.WebhookCallbackURL,
@@ -201,9 +201,10 @@ class Voice(Common):
         return self.__PostMessage()
 
     """ Function to send message """
-    def SendMessage(self,**kwargs):
+    def SendMessage(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
@@ -220,18 +221,21 @@ class Voice(Common):
         if not self.MessageToPeople:
             return MessageResult(error="Missing MessageToPeople")
         
+        """
         if len(self.Keypads) > 0:
             for keypad in self.Keypads:
                 if keypad["PlayFile"] == "" and keypad["Play"] != "":
                     err_msg = "Keypad " + str(keypad["Tone"]) + str(": Use PlayFile='[file name]' instead of Play=xxx.")
                     return MessageResult(error=err_msg)
+        """
 
         return self.__PostMessage()
 
     """ Async Function to send message """
-    async def SendMessageAsync(self,**kwargs):
+    async def SendMessageAsync(self, **kwargs):
 
-        self.SetArgs(kwargs)
+        if kwargs != None and len(kwargs) > 0:
+            self.__init__(kwargs)
 
         if not self.Sender :
             return MessageResult(error="Empty Sender")
@@ -248,11 +252,13 @@ class Voice(Common):
         if not self.MessageToPeople:
             return MessageResult(error="Missing MessageToPeople")
         
+        """
         if len(self.Keypads) > 0:
             for keypad in self.Keypads:
                 if keypad["PlayFile"] == "" and keypad["Play"] != "":
                     err_msg = "Keypad " + str(keypad["Tone"]) + str(": Use PlayFile='[file name]' instead of Play=xxx.")
                     return MessageResult(error=err_msg)
+        """
 
         return await asyncio.create_task(self.__PostMessageAsync())
 
@@ -260,4 +266,4 @@ class Voice(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
-        return 'SMS(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
+        return 'Voice(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
